@@ -1,16 +1,16 @@
-from __future__ import annotations
+"""Automatically finds files in the current directory."""
+
+from __future__ import annotations  # Support of `|` for type union in Python 3.9
 
 import os
 
 
 def autofinder():
-    """Automatically finds
-    suitable .diagnose and .notion
-    files in the current working directory
-    and yields them
+    """Automatically finds suitable .diagnose and .notion
+    files in the current working directory and yields them
     """
 
-    for root, dirs, files in os.walk("."):
+    for _, _, files in os.walk("."):
         for file in files:
             if os.path.basename(file).endswith(".diagnose"):
                 yield ("notion", file)
